import parse_csv
import diagram

caption = ''


def leaks(table):
    count = table.max('level')
    values = []
    count_survival = table.count_if('mode', '"{}"=="survival"')
    print 'Level:\tCount events'
    for level in xrange(count + 1):
        value = table.count_if('level', '{}==%s' % level)
        print '{}\t{}'.format(level, value)
        values.append(value)
    values[0] -= count_survival
    diagram.build(values, caption, 'levels_first_finish.png', total_as_max=True)


def main(argv):
    global caption
    file = 'LevelFirstFinish.csv'
    if len(argv) > 1:
        file = argv[1]
    table = parse_csv.parse(file)
    table.save('LevelFirstFinish_raw.txt')
    caption = 'Leaks on levels\n' + file
    leaks(table)

if __name__ == '__main__':
    main([])



from PIL import Image, ImageFont, ImageDraw, ImageOps

color_back = (255, 255, 255, 255)
color = (0, 255, 255, 255)
color2 = (255, 128, 255, 255)
width = 20
space = 2
font = ImageFont.load_default()


def draw_rotated_text(image, text, x, y):
    txt = Image.new('RGBA', (250, 50), (0, 0, 0, 0))
    d = ImageDraw.Draw(txt)
    d.text((0, 0), text, font=font, fill=(0, 0, 0, 192))
    txt = txt.rotate(90,  expand=1)
    px = x
    py = y
    sx = 50
    sy = 250
    image.paste(txt, (px, py, px + sx, py + sy), txt)


def build(values, caption, file, total_as_max=False, add_text='', values2=None, add_to_index=1):
    iwidth = len(values) * (width + space) + space
    iwidth = max(iwidth, 700)
    iheight = 500
    image = Image.new("RGBA", (iwidth, iheight), color_back)

    draw = ImageDraw.Draw(image)
    # draw.rectangle(((0, 00), (100, 100)), fill=color)
    if len(values) > 0:
        max_value = float(max(values))
        if values2:
            max_value += max(values2)

        x = space
        total = float(sum(values))
        for i, value in enumerate(values):
            print value, max_value, iheight, value / max_value * (iheight - 100)
            height = value / max_value * (iheight - 100)
            bottom = iheight - 20
            top = bottom - height
            draw.line((x, 50, x, iheight), fill=(0, 0, 0, 1))
            draw.text((x + 5, bottom), str(i + add_to_index), fill='black', font=font)

            draw.rectangle(((x, bottom), (x + width, top)), fill=color)
            if(values2):
                value2 = values2[i]
                height2 = value2 / max_value * (iheight - 100)
                bottom2 = top
                top2 = bottom2 - height2
                draw.rectangle(((x, bottom2), (x + width, top2)), fill=color2)

            if values2 is None:
                t = max_value if total_as_max else total
                text = str(value) + ' ({}%)'.format(round(value / t * 100, 1))
                draw_rotated_text(image, text, x + width / 5, image.height - 275)
            else:
                t = max_value if total_as_max else total
                text = '{}/{} ({}/{}%)'.format(value, values2[i],
                                               round(value / t * 100, 1), round(values2[i] / t * 100, 1))

                draw_rotated_text(image, text, x + width / 5, image.height - 275)

            x += width + space

    if len(add_text) > 0:
        draw.text((iwidth / 2, 50), add_text, fill='black', font=font)

    draw.text((10, 10), caption, fill='black', font=font)
    image.save(file)



import httplib2
import os

from apiclient import discovery
from oauth2client import client
from oauth2client import tools
from oauth2client.file import Storage


class GoogleSheets:

    def __init__(self,
                 APPLICATION_NAME='Google Sheets API Python Quickstart',
                 SCOPES='https://www.googleapis.com/auth/spreadsheets.readonly',
                 CLIENT_SECRET_FILE=''
                 ):
        self.application_name = APPLICATION_NAME
        self.scopes = SCOPES
        self.client_secret_file = CLIENT_SECRET_FILE
        self.flags = tools.argparser.parse_args(args=[])

        self.credentials = self._get_credentials()
        http = self.credentials.authorize(httplib2.Http())
        discoveryUrl = ('https://sheets.googleapis.com/$discovery/rest?' 'version=v4')
        self.service = discovery.build('sheets', 'v4', http=http, discoveryServiceUrl=discoveryUrl)

    def set_document(self, spreadsheetId):
        self.spreadsheetId = spreadsheetId

    def _get_credentials(self):
        home_dir = os.path.expanduser('~')
        credential_dir = os.path.join(home_dir, '.credentials')
        if not os.path.exists(credential_dir):
            os.makedirs(credential_dir)
        credential_path = os.path.join(credential_dir,
                                       'sheets.googleapis.com-python-quickstart.json')

        store = Storage(credential_path)
        credentials = store.get()
        if not credentials or credentials.invalid:
            flow = client.flow_from_clientsecrets(self.client_secret_file, self.scopes)
            flow.user_agent = self.application_name
            if self.flags:
                credentials = tools.run_flow(flow, store, self.flags)
            else:
                # Needed only for compatibility with Python 2.6
                # credentials = tools.run(flow, store)
                exit(-1)
            print 'Storing credentials to ' + credential_path
        return credentials

    def read_range(self, sheet, cell_from, cell_to):
        rangeName = '{}!{}:{}'.format(sheet, cell_from, cell_to)
        result = self.service.spreadsheets().values().get(
            spreadsheetId=self.spreadsheetId, range=rangeName).execute()
        values = result.get('values', [])
        max_length = 0
        for line in values:
            max_length = max(max_length, len(line))
        for line in values:
            while len(line) < max_length:
                line.append('')
        return values

    def convert_range_to_dictionary_table(self, range):
        dict_ = {}
        for line in range:
            if not line:
                continue
            dict_[line[0]] = line[1:]
        return dict_

    def get_sheet_titles(self):
        sheet_metadata = self.service.spreadsheets().get(spreadsheetId=self.spreadsheetId).execute()
        sheets = sheet_metadata.get('sheets', '')
        titles = []
        for sheet in sheets:
            sheet_id = sheet.get("properties", {}).get("title", 0).encode('utf-8')
            titles.append(sheet_id)
        return titles


def main():
    gs = GoogleSheets()
    gs.set_document('1WvxSOHiH-AnoMhPek-mbIqkVgwboGYKrecjueGvT5jE')
    raw = gs.read_range(gs.get_sheet_titles()[0], 'A1', 'Z')
    for row in raw:
        print row


if __name__ == '__main__':
    main()
